pub struct CacheKey {
pub path: Option<PathBuf>,
pub content_hash: u64,
}Expand description
Cache key for templates, combining path and content hash.
Fields
path: Option<PathBuf>File path (if loaded from file)
content_hash: u64Hash of template content
Implementations
Sourceimpl CacheKey
impl CacheKey
Sourcepub fn from_template(template: &TronTemplate) -> Self
pub fn from_template(template: &TronTemplate) -> Self
Create a new cache key from a template.
Sourcepub fn from_content(content: &str, path: Option<&Path>) -> Self
pub fn from_content(content: &str, path: Option<&Path>) -> Self
Create a cache key from content and optional path.